# nbxmpp-client

A small GTK test client to test various ways to connect to a server.

[[_TOC_]]

## Installation

	$ pip install nbxmpp-client

While developing, you can use:

	$ pip install -e .

## Usage

	$ nbc


## Runtime Requirements

- [Gtk4](https://gitlab.com/gnome/gtk) (>=4.8.0)
- [GtkSourceView5](https://gitlab.gnome.org/GNOME/gtksourceview) (>=5.6.0)
- [libadwaita](https://gitlab.gnome.org/GNOME/libadwaita) (>=1.2)
- [Python](https://www.python.org/) (>=3.10)
- [nbxmpp](https://pypi.org/project/nbxmpp/) (>=4.0.0)


## Build Requirements

- [setuptools](https://pypi.org/project/setuptools/) (>=65.0.0)
